@@ -14,33 +14,32 @@ logger = logging.getLogger(__name__)
 
 
 def region_pT(p, T):
-    """function region_pT = region_pT(p, T)
-    """
+    """function region_pT = region_pT(p, T)"""
     if (T > 1073.15) and (p < 50.0) and (T < 2273.15) and (p > 0.000611):
-        region_pT = 5
+        region_pT_number = 5
     elif (T <= 1073.15) and (T > 273.15) and (p <= 100) and (p > 0.000611):
         if T > 623.15:
             if p > RegionBorders.B23p_T(T):
-                region_pT = 3
+                region_pT_number = 3
                 if T < 647.096:
                     ps = Region4.p4_T(T)
                     if math.fabs(p - ps) < 0.00001:
-                        region_pT = 4
+                        region_pT_number = 4
             else:
-                region_pT = 2
+                region_pT_number = 2
         else:
             ps = Region4.p4_T(T)
             if math.fabs(p - ps) < 0.00001:
-                region_pT = 4
+                region_pT_number = 4
             elif p > ps:
-                region_pT = 1
+                region_pT_number = 1
             else:
-                region_pT = 2
+                region_pT_number = 2
     else:
         logger.warning("Temperature outside valid area")
-        region_pT = 0  # **Error, Outside valid area
+        region_pT_number = 0  # **Error, Outside valid area
 
-    return region_pT
+    return region_pT_number
 
 
 def region_ph(p, h):
@@ -57,16 +56,22 @@ def region_ph(p, h):
         if h < Region1.h1_pT(p, 273.15):
             logger.warning("Enthalpy outside valid area")
             return 0
-    if p < 16.5292:  # Bellow region 3, Check region 1, 4, 2, 5
+    if p < 16.5292:  # Below region 3, Check region 1, 4, 2, 5
         # Check Region 1
         Ts = Region4.T4_p(p)
-        hL = 109.6635 * math.log(p) + 40.3481 * p + 734.58  # Approximate function for hL_p
-        if math.fabs(h - hL) < 100:  # if approximate is not god enough use real function
+        hL = (
+            109.6635 * math.log(p) + 40.3481 * p + 734.58
+        )  # Approximate function for hL_p
+        if (
+            math.fabs(h - hL) < 100
+        ):  # if approximate is not god enough use real function
             hL = Region1.h1_pT(p, Ts)
         if h <= hL:
             return 1
         # Check Region 4
-        hV = 45.1768 * math.log(p) - 20.158 * p + 2804.4  # Approximate function for hV_p
+        hV = (
+            45.1768 * math.log(p) - 20.158 * p + 2804.4
+        )  # Approximate function for hV_p
         if math.fabs(h - hV) < 50:  # if approximate is not god enough use real function
             hV = Region2.h2_pT(p, Ts)
         if h < hV:
@@ -92,7 +97,7 @@ def region_ph(p, h):
         if h < Region1.h1_pT(p, 623.15):
             # region_ph = 1;
             return 1
-        # Check if in region 3 or 4 (Bellow Reg 2)
+        # Check if in region 3 or 4 (Below Reg 2)
         if h < Region2.h2_pT(p, RegionBorders.B23T_p(p)):
             # Region 3 or 4
             if p > RegionBorders.p3sat_h(h):
@@ -107,7 +112,7 @@ def region_ph(p, h):
 
 
 def region_ps(p, s):
-    """ function region_ps = region_ps(p, s)
+    """function region_ps = region_ps(p, s)
 
     Section 3.3 Regions as a function of ps
     """
@@ -123,7 +128,9 @@ def region_ps(p, s):
             return 0
     # Check region 2
     if p > 16.529:
-        ss = Region2.s2_pT(p, RegionBorders.B23T_p(p))  # Between 5.047 & 5.261. Use to speed up !
+        ss = Region2.s2_pT(
+            p, RegionBorders.B23T_p(p)
+        )  # Between 5.047 & 5.261. Use to speed up !
     else:
         ss = Region2.s2_pT(p, Region4.T4_p(p))
     if s > ss:
@@ -152,8 +159,8 @@ def region_hs(h, s):
     if s < -0.0001545495919:
         logger.warning("Entropy outside valid area")
         return 0
-    # Check linear adaption to p=0.000611. if bellow region 4.
-    hMin = (((-0.0415878 - 2500.89262) / (-0.00015455 - 9.155759)) * s)
+    # Check linear adaption to p=0.000611. if below region 4.
+    hMin = ((-0.0415878 - 2500.89262) / (-0.00015455 - 9.155759)) * s
     if (s < 9.155759395) and (h < hMin):
         logger.warning("Entalpy or Entropy outside valid area")
         return 0
@@ -188,7 +195,13 @@ def region_hs(h, s):
             Tmin = Region2.T2_ps(0.000611, s)
             hMin = Region2.h2_pT(0.000611, Tmin)
             # function adapted to h(1073.15,s)
-            hMax = -0.07554022 * s ** 4 + 3.341571 * s ** 3 - 55.42151 * s ** 2 + 408.515 * s + 3031.338
+            hMax = (
+                -0.07554022 * s**4
+                + 3.341571 * s**3
+                - 55.42151 * s**2
+                + 408.515 * s
+                + 3031.338
+            )
             if (h > hMin) and (h < hMax):
                 return 2
             else:
@@ -202,7 +215,13 @@ def region_hs(h, s):
             hMax = Region2.h2_pT(100, TMax)
         else:
             # function adapted to h(1073.15,s)
-            hMax = -2.988734 * s ** 4 + 121.4015 * s ** 3 - 1805.15 * s ** 2 + 11720.16 * s - 23998.33
+            hMax = (
+                -2.988734 * s**4
+                + 121.4015 * s**3
+                - 1805.15 * s**2
+                + 11720.16 * s
+                - 23998.33
+            )
         if h < hMax:  # Region 2. ???ver region 4.
             return 2
         else:
@@ -249,7 +268,9 @@ def region_hs(h, s):
                 else:
                     logger.warning("Entropy outside valid area")
                     return 0
-            if h < 2563.592004:  # Nedanf???r B23 i h_led men vi har redan kollat ovanf???r hV2c3b
+            if (
+                h < 2563.592004
+            ):  # Nedanf???r B23 i h_led men vi har redan kollat ovanf???r hV2c3b
                 return 3
             # Vi ???r inom b23 omr???det i b???de s och h led.
             Tact = RegionBorders.TB23_hs(h, s)
@@ -272,8 +293,10 @@ def region_prho(p, rho):
     if (p < 0.000611657) or (p > 100):
         logger.warning("Preasure outside valid area")
         return 0
-    if p < 16.5292:  # Bellow region 3, Check region 1,4,2
-        if v < Region1.v1_pT(p, 273.15):  # Observe that this is not actually min of v. Not valid Water of 4???C is ligther.
+    if p < 16.5292:  # Below region 3, Check region 1,4,2
+        if v < Region1.v1_pT(
+            p, 273.15
+        ):  # Observe that this is not actually min of v. Not valid Water of 4???C is ligther.
             logger.warning("Specific volume outside valid area")
             return 0
         if v <= Region1.v1_pT(p, Region4.T4_p(p)):
@@ -288,17 +311,21 @@ def region_prho(p, rho):
         if v <= Region5.v5_pT(p, 2073.15):
             return 5
     else:  # Check region 1,3,4,3,2 (Above the lowest point of region 3.)
-        if v < Region1.v1_pT(p, 273.15):  # Observe that this is not actually min of v. Not valid Water of 4???C is ligther.
+        if v < Region1.v1_pT(
+            p, 273.15
+        ):  # Observe that this is not actually min of v. Not valid Water of 4???C is ligther.
             logger.warning("Specific volume outside valid area")
             return 0
         if v < Region1.v1_pT(p, 623.15):
             return 1
-        # Check if in region 3 or 4 (Bellow Reg 2)
+        # Check if in region 3 or 4 (Below Reg 2)
         if v < Region2.v2_pT(p, RegionBorders.B23T_p(p)):
             # Region 3 or 4
             if p > 22.064:  # Above region 4
                 return 3
-            if (v < Region3.v3_ph(p, Region4.h4L_p(p))) or (v > Region3.v3_ph(p, Region4.h4V_p(p))):  # Uses iteration!!
+            if (v < Region3.v3_ph(p, Region4.h4L_p(p))) or (
+                v > Region3.v3_ph(p, Region4.h4V_p(p))
+            ):  # Uses iteration!!
                 return 3
             else:
                 return 4
